@@ -9,10 +9,10 @@
 #  ifndef AKONADI_EXPORT
 #    ifdef akonadi_kde
         /* We are building this library */
-#      define AKONADI_EXPORT 
+#      define AKONADI_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_EXPORT 
+#      define AKONADI_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
