@@ -9,10 +9,10 @@
 #  ifndef AKONADI_CALENDAR_EXPORT
 #    ifdef akonadi_calendar
         /* We are building this library */
-#      define AKONADI_CALENDAR_EXPORT 
+#      define AKONADI_CALENDAR_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_CALENDAR_EXPORT 
+#      define AKONADI_CALENDAR_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
