@@ -9,10 +9,10 @@
 #  ifndef AKONADI_CONTACT_EXPORT
 #    ifdef akonadi_contact
         /* We are building this library */
-#      define AKONADI_CONTACT_EXPORT 
+#      define AKONADI_CONTACT_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_CONTACT_EXPORT 
+#      define AKONADI_CONTACT_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
