@@ -9,10 +9,10 @@
 #  ifndef AKONADI_KABC_EXPORT
 #    ifdef akonadi_kabc
         /* We are building this library */
-#      define AKONADI_KABC_EXPORT 
+#      define AKONADI_KABC_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_KABC_EXPORT 
+#      define AKONADI_KABC_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
