@@ -9,10 +9,10 @@
 #  ifndef AKONADI_KCAL_EXPORT
 #    ifdef akonadi_kcal
         /* We are building this library */
-#      define AKONADI_KCAL_EXPORT 
+#      define AKONADI_KCAL_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_KCAL_EXPORT 
+#      define AKONADI_KCAL_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
