@@ -9,10 +9,10 @@
 #  ifndef AKONADI_KMIME_EXPORT
 #    ifdef akonadi_kmime
         /* We are building this library */
-#      define AKONADI_KMIME_EXPORT 
+#      define AKONADI_KMIME_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_KMIME_EXPORT 
+#      define AKONADI_KMIME_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
