@@ -9,10 +9,10 @@
 #  ifndef AKONADI_NOTES_EXPORT
 #    ifdef akonadi_notes
         /* We are building this library */
-#      define AKONADI_NOTES_EXPORT 
+#      define AKONADI_NOTES_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_NOTES_EXPORT 
+#      define AKONADI_NOTES_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
