@@ -9,10 +9,10 @@
 #  ifndef LIBAKONADISOCIALUTILS_EXPORT
 #    ifdef akonadi_socialutils
         /* We are building this library */
-#      define LIBAKONADISOCIALUTILS_EXPORT 
+#      define LIBAKONADISOCIALUTILS_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define LIBAKONADISOCIALUTILS_EXPORT 
+#      define LIBAKONADISOCIALUTILS_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
