@@ -9,10 +9,10 @@
 #  ifndef AKONADI_XML_EXPORT
 #    ifdef MAKE_AKONADI_XML_LIB
         /* We are building this library */
-#      define AKONADI_XML_EXPORT 
+#      define AKONADI_XML_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define AKONADI_XML_EXPORT 
+#      define AKONADI_XML_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
