@@ -9,10 +9,10 @@
 #  ifndef GPGMEPP_EXPORT
 #    ifdef gpgmepp_EXPORTS
         /* We are building this library */
-#      define GPGMEPP_EXPORT 
+#      define GPGMEPP_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define GPGMEPP_EXPORT 
+#      define GPGMEPP_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
