@@ -9,10 +9,10 @@
 #  ifndef KABC_EXPORT
 #    ifdef kabc_EXPORTS
         /* We are building this library */
-#      define KABC_EXPORT 
+#      define KABC_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KABC_EXPORT 
+#      define KABC_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
