@@ -9,10 +9,10 @@
 #  ifndef KALARMCAL_EXPORT
 #    ifdef kalarmcal_EXPORTS
         /* We are building this library */
-#      define KALARMCAL_EXPORT 
+#      define KALARMCAL_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KALARMCAL_EXPORT 
+#      define KALARMCAL_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
