@@ -9,10 +9,10 @@
 #  ifndef KBLOG_EXPORT
 #    ifdef kblog_EXPORTS
         /* We are building this library */
-#      define KBLOG_EXPORT 
+#      define KBLOG_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KBLOG_EXPORT 
+#      define KBLOG_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
