@@ -9,10 +9,10 @@
 #  ifndef KCAL_EXPORT
 #    ifdef kcal_EXPORTS
         /* We are building this library */
-#      define KCAL_EXPORT 
+#      define KCAL_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KCAL_EXPORT 
+#      define KCAL_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
