@@ -9,10 +9,10 @@
 #  ifndef KCALCORE_EXPORT
 #    ifdef kcalcore_EXPORTS
         /* We are building this library */
-#      define KCALCORE_EXPORT 
+#      define KCALCORE_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KCALCORE_EXPORT 
+#      define KCALCORE_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
