@@ -9,10 +9,10 @@
 #  ifndef KCALUTILS_EXPORT
 #    ifdef kcalutils_EXPORTS
         /* We are building this library */
-#      define KCALUTILS_EXPORT 
+#      define KCALUTILS_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KCALUTILS_EXPORT 
+#      define KCALUTILS_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
