@@ -9,10 +9,10 @@
 #  ifndef KHOLIDAYS_EXPORT
 #    ifdef kholidays_EXPORTS
         /* We are building this library */
-#      define KHOLIDAYS_EXPORT 
+#      define KHOLIDAYS_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KHOLIDAYS_EXPORT 
+#      define KHOLIDAYS_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
