@@ -9,10 +9,10 @@
 #  ifndef KIMAP_EXPORT
 #    ifdef kimap_EXPORTS
         /* We are building this library */
-#      define KIMAP_EXPORT 
+#      define KIMAP_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KIMAP_EXPORT 
+#      define KIMAP_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
