@@ -9,10 +9,10 @@
 #  ifndef KLDAP_EXPORT
 #    ifdef kldap_EXPORTS
         /* We are building this library */
-#      define KLDAP_EXPORT 
+#      define KLDAP_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KLDAP_EXPORT 
+#      define KLDAP_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
