@@ -9,10 +9,10 @@
 #  ifndef KMBOX_EXPORT
 #    ifdef kmbox_EXPORTS
         /* We are building this library */
-#      define KMBOX_EXPORT 
+#      define KMBOX_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KMBOX_EXPORT 
+#      define KMBOX_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
