@@ -9,10 +9,10 @@
 #  ifndef KMIME_EXPORT
 #    ifdef kmime_EXPORTS
         /* We are building this library */
-#      define KMIME_EXPORT 
+#      define KMIME_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KMIME_EXPORT 
+#      define KMIME_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
