@@ -9,10 +9,10 @@
 #  ifndef KONTACTINTERFACE_EXPORT
 #    ifdef kontactinterface_EXPORTS
         /* We are building this library */
-#      define KONTACTINTERFACE_EXPORT 
+#      define KONTACTINTERFACE_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KONTACTINTERFACE_EXPORT 
+#      define KONTACTINTERFACE_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
