@@ -9,10 +9,10 @@
 #  ifndef KPIMIDENTITIES_EXPORT
 #    ifdef kpimidentities_EXPORTS
         /* We are building this library */
-#      define KPIMIDENTITIES_EXPORT 
+#      define KPIMIDENTITIES_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KPIMIDENTITIES_EXPORT 
+#      define KPIMIDENTITIES_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
