@@ -9,10 +9,10 @@
 #  ifndef KPIMTEXTEDIT_EXPORT
 #    ifdef kpimtextedit_EXPORTS
         /* We are building this library */
-#      define KPIMTEXTEDIT_EXPORT 
+#      define KPIMTEXTEDIT_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KPIMTEXTEDIT_EXPORT 
+#      define KPIMTEXTEDIT_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
