@@ -9,10 +9,10 @@
 #  ifndef KPIMUTILS_EXPORT
 #    ifdef kpimutils_EXPORTS
         /* We are building this library */
-#      define KPIMUTILS_EXPORT 
+#      define KPIMUTILS_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KPIMUTILS_EXPORT 
+#      define KPIMUTILS_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
