@@ -9,10 +9,10 @@
 #  ifndef KRESOURCES_EXPORT
 #    ifdef kresources_EXPORTS
         /* We are building this library */
-#      define KRESOURCES_EXPORT 
+#      define KRESOURCES_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KRESOURCES_EXPORT 
+#      define KRESOURCES_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
