@@ -9,10 +9,10 @@
 #  ifndef KTNEF_EXPORT
 #    ifdef ktnef_EXPORTS
         /* We are building this library */
-#      define KTNEF_EXPORT 
+#      define KTNEF_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KTNEF_EXPORT 
+#      define KTNEF_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
