@@ -9,10 +9,10 @@
 #  ifndef KXMLRPCCLIENT_EXPORT
 #    ifdef kxmlrpcclient_EXPORTS
         /* We are building this library */
-#      define KXMLRPCCLIENT_EXPORT 
+#      define KXMLRPCCLIENT_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define KXMLRPCCLIENT_EXPORT 
+#      define KXMLRPCCLIENT_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
