@@ -9,10 +9,10 @@
 #  ifndef MAILTRANSPORT_EXPORT
 #    ifdef mailtransport_EXPORTS
         /* We are building this library */
-#      define MAILTRANSPORT_EXPORT 
+#      define MAILTRANSPORT_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define MAILTRANSPORT_EXPORT 
+#      define MAILTRANSPORT_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
