@@ -9,10 +9,10 @@
 #  ifndef MICROBLOG_EXPORT
 #    ifdef microblog_EXPORTS
         /* We are building this library */
-#      define MICROBLOG_EXPORT 
+#      define MICROBLOG_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define MICROBLOG_EXPORT 
+#      define MICROBLOG_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
