@@ -9,10 +9,10 @@
 #  ifndef QGPGME_EXPORT
 #    ifdef qgpgme_EXPORTS
         /* We are building this library */
-#      define QGPGME_EXPORT 
+#      define QGPGME_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define QGPGME_EXPORT 
+#      define QGPGME_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
