@@ -9,10 +9,10 @@
 #  ifndef SYNDICATION_EXPORT
 #    ifdef syndication_EXPORTS
         /* We are building this library */
-#      define SYNDICATION_EXPORT 
+#      define SYNDICATION_EXPORT __declspec(dllexport)
 #    else
         /* We are using this library */
-#      define SYNDICATION_EXPORT 
+#      define SYNDICATION_EXPORT __declspec(dllimport)
 #    endif
 #  endif
 
